@@ -1,7 +1,7 @@
 # SPDX-License-Identifier: GPL-2.0-only
 # Copyright (c) 2019-2020 NITK Surathkal
 
-"""ip address commands"""
+"""IP address commands"""
 
 from .exec import exec_subprocess
 
@@ -18,5 +18,5 @@ def assign_ip(host_name, dev_name, ip_address):
     ip_address : str
         ip address to be assigned to the interface
     """
-    #TODO: Support for ipv6
+    #TODO: Support for IPv6
     exec_subprocess(f'ip netns exec {host_name} ip address add {ip_address} dev {dev_name}')
