@@ -1,7 +1,7 @@
 # SPDX-License-Identifier: GPL-2.0-only
 # Copyright (c) 2019-2020 NITK Surathkal
 
-"""ip route commands"""
+"""IP route commands"""
 
 from .exec import exec_subprocess
 
