@@ -26,7 +26,7 @@ class SsRunner(Runner):
     ns_id : str
         network namespace to run ss from
     destination_ip : str
-        ip address of the destination namespace
+        IP address of the destination namespace
     start_time : num
         time at which ss is to be run
     run_time : num
@@ -46,7 +46,7 @@ class SsRunner(Runner):
         ns_id : str
             network namespace to run ss from
         destination_ip : str
-            ip address of the destination namespace
+            IP address of the destination namespace
         start_time : num
             time at which ss is to be run
         run_time : num
@@ -101,7 +101,7 @@ class SsRunner(Runner):
                 timestamp_pattern, raw_stat).group("timestamp")
 
             for port in port_list:
-                # If port encoutered first time
+                # If port encountered first time
                 if port not in stats_dict_list:
                     stats_dict_list[port] = [self.get_meta_item()]
 
@@ -121,7 +121,7 @@ class SsRunner(Runner):
                     if param_value.endswith('bps'):
                         param_value = self.convert_to(param_value)
                     try:
-                        # rtt has both avg and dev rtt separated by a /
+                        # RTT has both average and RTT deviation separated by a /
                         if param == 'rtt':
                             avg_rtt = param_value.split('/')[0]
                             dev_rtt = param_value.split('/')[1]
@@ -135,13 +135,6 @@ class SsRunner(Runner):
 
         SsResults.add_result(
             self.ns_id, {self.destination_ip: stats_dict_list})
-        self.clean_up()
-
-    def clean_up(self):
-        """
-        Closes the temp files created
-        """
-        return super().clean_up()
 
     @staticmethod
     def convert_to(param_value, unit_out='Mbps'):
@@ -151,8 +144,8 @@ class SsRunner(Runner):
         converter = {'bps': 1, 'Kbps': 1e3, 'Mbps': 1e6, 'Gbps': 1e9}
 
         # Extract value and unit
-        unit_in = re.sub(r'[0-9]', '', param_value)
-        extracted_param_value = float(re.sub(r'[A-Za-z]', '', param_value))
+        unit_in = re.sub(r'^\d*\.?\d*', '', param_value)
+        extracted_param_value = float(re.sub(r'[A-Za-z]*', '', param_value))
 
         converted_param_value = str(extracted_param_value * converter[unit_in]/converter[unit_out])
         return converted_param_value
