@@ -5,8 +5,9 @@
 
 from .. import config
 
-class IdGen:
-    """Generate unique id for Topology entites
+class IdGen: # pylint: disable=too-few-public-methods
+    """Generate unique id for Topology entities
+
 
     Attributes
     ----------
@@ -21,7 +22,6 @@ class IdGen:
     """
     topology_id = ""
     counter = 0
-    is_unique_id = config.get_value('assign_random_names')
 
     def __init__(self, topology_id):
         """Initialize `topology_id`
@@ -49,24 +49,8 @@ class IdGen:
             Else, `name` is returned back
 
         """
-        if IdGen.is_unique_id:
+        if config.get_value('assign_random_names'):
             IdGen.counter += 1
             return IdGen.topology_id+"-"+str(IdGen.counter)
 
         return name
-
-    @staticmethod
-    def enable_unique_id():
-        """
-        If disabled, enable generation of unique id
-
-        """
-        IdGen.is_unique_id = True
-
-    @staticmethod
-    def disable_unique_id():
-        """
-        If enabled, disable generation of unique id
-
-        """
-        IdGen.is_unique_id = False
